@@ -100,7 +100,7 @@ void ResourceLinking::LinkResourceToActivity(QString initiatingAgent,
 
     DATABASE_TRANSACTION(*resourcesDatabase());
 
-    Utils::exec(Utils::FailOnError, *linkResourceToActivityQuery,
+    Utils::exec(*resourcesDatabase(), Utils::FailOnError, *linkResourceToActivityQuery,
         ":usedActivity"      , usedActivity,
         ":initiatingAgent"   , initiatingAgent,
         ":targettedResource" , targettedResource
@@ -173,12 +173,12 @@ void ResourceLinking::UnlinkResourceFromActivity(QString initiatingAgent,
 
     DATABASE_TRANSACTION(*resourcesDatabase());
     // BUG 385814, some existings entries don't have the applications:
-    // prefix, so we remove it and check in the sql it they match
-    // TODO Remove when we can expect all users have a fresher install that 5.18
+    // prefix, so we remove it and check in the sql if they match
+    // TODO Remove when we can expect all users to have a fresher install than 5.18
     if (initiatingAgent == QLatin1String("org.kde.plasma.favorites.applications")) {
         targettedResource = targettedResource.remove(QLatin1String("applications:"));
     }
-    Utils::exec(Utils::FailOnError, *query,
+    Utils::exec(*resourcesDatabase(), Utils::FailOnError, *query,
         ":usedActivity"      , usedActivity,
         ":initiatingAgent"   , initiatingAgent,
         ":targettedResource" , targettedResource
@@ -231,7 +231,7 @@ bool ResourceLinking::IsResourceLinkedToActivity(QString initiatingAgent,
             "targettedResource = COALESCE(:targettedResource, '') "
         ));
 
-    Utils::exec(Utils::FailOnError, *isResourceLinkedToActivityQuery,
+    Utils::exec(*resourcesDatabase(), Utils::FailOnError, *isResourceLinkedToActivityQuery,
         ":usedActivity"      , usedActivity,
         ":initiatingAgent"   , initiatingAgent,
         ":targettedResource" , targettedResource
